@@ -1,4 +1,4 @@
-/* ID: fastmatrix.h, last updated 2022-08-01, F.Osorio */
+/* ID: fastmatrix.h, last updated 2024-01-03, F.Osorio */
 
 #ifndef FASTMATRIX_H
 #define FASTMATRIX_H
@@ -69,6 +69,7 @@ double FM_sum_upper_tri(double *x, int ldx, int p, int job);
 
 /* matrix factorizations */
 void FM_chol_decomp(double *a, int lda, int p, int job, int *info);
+void FM_lu_decomp(double *a, int lda, int n, int p, int *pivot, int *info);
 void FM_QR_decomp(double *mat, int ldmat, int nrow, int ncol, double *qraux, int *info);
 void FM_QL_decomp(double *mat, int ldmat, int nrow, int ncol, double *qlaux, int *info);
 void FM_LQ_decomp(double *mat, int ldmat, int nrow, int ncol, double *lqaux, int *info);
@@ -91,6 +92,8 @@ void FM_forwardsolve(double *l, int ldl, int n, double *b, int ldb, int nrhs, in
 void FM_chol_inverse(double *a, int lda, int p, int job, int *info);
 void FM_invert_mat(double *a, int lda, int n, int *info);
 void FM_invert_triangular(double *a, int lda, int n, int job, int *info);
+void FM_lu_inverse(double *a, int lda, int p, int *pivot, int *info);
+void FM_lu_solve(double *a, int lda, int p, int *pivot, double *b, int ldb, int nrhs, int *info);
 
 /* least square procedures */
 void FM_lsfit(double *x, int ldx, int nrow, int ncol, double *y, int ldy, int nrhs, double *coef, int *info);
@@ -100,8 +103,12 @@ void FM_gls_GQR(double *x, int ldx, int nrow, int ncol, double *y, double *cov,
 double FM_pythag(double a, double b);
 double FM_mahalanobis(double *x, int p, double *center, double *Root);
 void FM_mahal_distances(double *x, int n, int p, double *center, double *cov, int inverted, double *distances);
+
+/* Wilson-Hilferty transformation */
 void FM_WH_chisq(double *distances, int n, int p, double *z);
+void FM_WH_gamma(double *y, int n, double shape, double scale, double *z);
 void FM_WH_F(double *distances, int n, int p, double eta, double *z);
+void FM_WH_Laplace(double *distances, int n, int p, double *z);
 
 /* products */
 void FM_two_product_FMA(double a, double b, double *x, double *y);
