@@ -1,4 +1,4 @@
-/* $ID: fastmatrix_API.h, last updated 2022-10-06, F.Osorio */
+/* $ID: fastmatrix_API.h, last updated 2024-01-03, F.Osorio */
 
 #ifndef FASTMATRIX_API_H
 #define FASTMATRIX_API_H
@@ -420,6 +420,13 @@ void FM_chol_decomp(double *a, int lda, int p, int job, int *info) {
   fun(a, lda, p, job, info);
 }
 
+void FM_lu_decomp(double *a, int lda, int n, int p, int *pivot, int *info) {
+  static void(*fun)(double *, int, int, int, int *, int *) = NULL;
+  if (fun == NULL)
+    fun = (void(*)(double *, int, int, int, int *, int *)) R_GetCCallable("fastmatrix", "FM_lu_decomp");
+  fun(a, lda, n, p, pivot, info);
+}
+
 void FM_QR_decomp(double *mat, int ldmat, int nrow, int ncol, double *qraux, int *info) {
   static void(*fun)(double *, int, int, int, double *, int *) = NULL;
   if (fun == NULL)
@@ -481,11 +488,11 @@ void FM_QR_fitted(double *qr, int ldq, int nrow, int ncol, double *qraux, double
   fun(qr, ldq, nrow, ncol, qraux, ymat, ldy, yrow, ycol, job, fitted);
 }
 
-void FM_QR_store_R(double *qr, int ldq, int nrow, int ncol, double *Dest, int ldDest) {
-  static void(*fun)(double *, int, int, int, double *, int) = NULL;
+void FM_QR_store_R(double *qr, int ldq, int ncol, double *Dest, int ldDest) {
+  static void(*fun)(double *, int, int, double *, int) = NULL;
   if (fun == NULL)
-    fun = (void(*)(double *, int, int, int, double *, int)) R_GetCCallable("fastmatrix", "FM_QR_store_R");
-  fun(qr, ldq, nrow, ncol, Dest, ldDest);
+    fun = (void(*)(double *, int, int, double *, int)) R_GetCCallable("fastmatrix", "FM_QR_store_R");
+  fun(qr, ldq, ncol, Dest, ldDest);
 }
 
 void FM_QL_qy(double *ql, int ldq, int nrow, int ncol, double *qlaux, double *ymat, int ldy, int yrow, int ycol, int *info) {
@@ -570,6 +577,20 @@ void FM_invert_triangular(double *a, int lda, int n, int job, int *info) {
   fun(a, lda, n, job, info);
 }
 
+void FM_lu_inverse(double *a, int lda, int p, int *pivot, int *info) {
+  static void(*fun)(double *, int, int, int *, int *) = NULL;
+  if (fun == NULL)
+    fun = (void(*)(double *, int, int, int *, int *)) R_GetCCallable("fastmatrix", "FM_lu_inverse");
+  fun(a, lda, p, pivot, info);
+}
+
+void FM_lu_solve(double *a, int lda, int p, int *pivot, double *b, int ldb, int nrhs, int *info) {
+  static void(*fun)(double *, int, int, int *, double *, int, int, int *) = NULL;
+  if (fun == NULL)
+    fun = (void(*)(double *, int, int, int *, double *, int, int, int *)) R_GetCCallable("fastmatrix", "FM_lu_solve");
+  fun(a, lda, p, pivot, b, ldb, nrhs, info);
+}
+
 /* ========================================================================== *
  * least square procedures: external API
  * ========================================================================== */
@@ -615,6 +636,17 @@ void FM_mahal_distances(double *x, int n, int p, double *center, double *cov, in
   fun(x, n, p, center, cov, inverted, distances);
 }
 
+/* ========================================================================== *
+ * Wilson-Hilferty transformation: external API
+ * ========================================================================== */
+
+void FM_WH_gamma(double *y, int n, double shape, double scale, double *z) {
+  static void(*fun)(double *, int, double, double, double *) = NULL;
+  if (fun == NULL)
+    fun = (void(*)(double *, int, double, double, double *)) R_GetCCallable("fastmatrix", "FM_WH_gamma");
+  fun(y, n, shape, scale, z);
+}
+
 void FM_WH_chisq(double *distances, int n, int p, double *z) {
   static void(*fun)(double *, int, int, double *) = NULL;
   if (fun == NULL)
@@ -629,6 +661,13 @@ void FM_WH_F(double *distances, int n, int p, double eta, double *z) {
   fun(distances, n, p, eta, z);
 }
 
+void FM_WH_Laplace(double *distances, int n, int p, double *z) {
+  static void(*fun)(double *, int, int, double *) = NULL;
+  if (fun == NULL)
+    fun = (void(*)(double *, int, int, double *)) R_GetCCallable("fastmatrix", "FM_WH_Laplace");
+  fun(distances, n, p, z);
+}
+
 /* ========================================================================== *
  * Products: external API
  * ========================================================================== */
